# *_bgnd_dist package_*

bgnd_dist is a Python module built using numpy and matplotlib libraries. It is distributed under license by MIT.

This package was created in 2022 as a personal exercise that has been tested and modified by professionals.

# _files_

The package has two parts -
The Binomial and Gaussian distributions: Both are used to calculate mean; standard deviation; gaussian distribution; and binomial distribution of a given data.
It also visualizes the data using barchart, histogram and calculate probability density function as well as plotting histogram-pdf chart

# _installation_

Just like any other Python package, it can install by simply running the command below on your terminal:

* **_pip install bgnd_dist_**

# dependencies

This package requires:

**_Python (>= 3.9)_**

**_NumPy (>= 1.17.3)_**

**_Matplotlib(>=3.1.2)_**